==> dvisvgm-2.0.4.tar.gz: dvisvgm-2.0.4/src/SVGCharHandlerFactory.hpp <==
/*************************************************************************
** SVGCharHandlerFactory.hpp                                            **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2016 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#ifndef SVGCHARHANDLERFACTORY_HPP
#define SVGCHARHANDLERFACTORY_HPP

#include "SVGCharHandler.hpp"


struct SVGCharHandlerFactory
{
	static SVGCharHandler* createHandler ();
};

#endif

==> dvisvgm-2.2.2.tar.gz: dvisvgm-2.2.2/src/SVGCharHandlerFactory.hpp <==
/*************************************************************************
** SVGCharHandlerFactory.hpp                                            **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2017 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#ifndef SVGCHARHANDLERFACTORY_HPP
#define SVGCHARHANDLERFACTORY_HPP

#include <memory>
#include "SVGCharHandler.hpp"

struct SVGCharHandlerFactory {
	static std::unique_ptr<SVGCharHandler> createHandler ();
};

#endif
